<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>نظام تسجيل المستخدمين</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body { background-color: #f8f9fa; font-family: 'Tahoma', Arial, sans-serif; }
        .form-container { background-color: white; border-radius: 10px; box-shadow: 0 0 15px rgba(0,0,0,0.1); padding: 30px; margin-top: 50px; }
        .form-title { color: #2c3e50; margin-bottom: 30px; text-align: center; }
        .required-field::after { content: " *"; color: red; }
    </style>
</head>
<body>
    <div class="container">
        <div class="row justify-content-center">
            <div class="col-md-8 form-container">
                <h2 class="form-title">تسجيل بيانات المستخدم</h2>
                <form id="userForm" method="post" action="save_user.php">
                    <div class="mb-3">
                        <label for="username" class="form-label required-field">اسم المستخدم</label>
                        <input type="text" class="form-control" id="username" name="username" required>
                    </div>
                    
                    <div class="mb-3">
                        <label for="nationalId" class="form-label required-field">الرقم القومي</label>
                        <input type="text" class="form-control" id="nationalId" name="nationalId" maxlength="14" required>
                        <div id="nationalIdError" class="text-danger"></div>
                    </div>
                    
                    <div class="mb-3">
                        <label for="government" class="form-label required-field">المحافظة</label>
                        <select class="form-select" id="government" name="government" required>
                            <option value="">اختر المحافظة</option>
                            <?php
                            $db = new mysqli('localhost', 'nceeeedu_naglaaw', 'plastic@-surgery', 'nceeeedu_Grade2test');
                            $result = $db->query("SELECT GovID, GovName FROM government ORDER BY GovName");
                            while ($row = $result->fetch_assoc()) {
                                echo "<option value='{$row['GovID']}'>{$row['GovName']}</option>";
                            }
                            ?>
                        </select>
                    </div>
                    
                    <div class="mb-3">
                        <label for="edara" class="form-label required-field">الإدارة التعليمية</label>
                        <select class="form-select" id="edara" name="edara" required disabled>
                            <option value="">اختر الإدارة التعليمية</option>
                        </select>
                    </div>
                    
                    <div class="mb-3">
                        <label for="school" class="form-label required-field">المدرسة</label>
                        <select class="form-select" id="school" name="school" required disabled>
                            <option value="">اختر المدرسة</option>
                        </select>
                    </div>
                    
                    <button type="submit" class="btn btn-primary w-100">حفظ البيانات</button>
                </form>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
        $(document).ready(function() {
            // Government change handler
            $('#government').change(function() {
                const govId = $(this).val();
                $('#edara').empty().append('<option value="">اختر الإدارة التعليمية</option>').prop('disabled', !govId);
                $('#school').empty().append('<option value="">اختر المدرسة</option>').prop('disabled', true);
                
                if (govId) {
                    $.ajax({
                        url: 'get_edarat.php',
                        method: 'POST',
                        data: { GovID: govId },
                        dataType: 'json',
                        success: function(edarat) {
                            edarat.forEach(edara => {
                                $('#edara').append(`<option value="${edara.EdaraID}">${edara.EdaraName}</option>`);
                            });
                            $('#edara').prop('disabled', false);
                        }
                    });
                }
            });
            
            // Edara change handler
            $('#edara').change(function() {
                const edaraId = $(this).val();
                $('#school').empty().append('<option value="">اختر المدرسة</option>').prop('disabled', !edaraId);
                
                if (edaraId) {
                    $.ajax({
                        url: 'get_schools.php',
                        method: 'POST',
                        data: { EdaraID: edaraId },
                        dataType: 'json',
                        success: function(schools) {
                            schools.forEach(school => {
                                $('#school').append(`<option value="${school.SchoolID}">${school.SchoolName}</option>`);
                            });
                            $('#school').prop('disabled', false);
                        }
                    });
                }
            });
            
            // National ID validation
            $('#nationalId').on('input', function() {
                const nationalId = $(this).val();
                const errorDiv = $('#nationalIdError');
                
                if (nationalId.length !== 14 || !/^\d+$/.test(nationalId)) {
                    errorDiv.text('الرقم القومي يجب أن يكون 14 رقمًا فقط');
                    return;
                }
                
                errorDiv.text('');
                
                $.ajax({
                    url: 'check_national_id.php',
                    method: 'POST',
                    data: { nationalId: nationalId },
                    success: function(response) {
                        if (response.exists) {
                            errorDiv.text('الرقم القومي مسجل بالفعل');
                        } else {
                            errorDiv.text('');
                        }
                    }
                });
            });
        });
    </script>
</body>
</html>